@@ -26,7 +26,7 @@
 #define GLOBUS_I_GSI_CREDENTIAL_H
 
 #include "globus_gsi_credential.h"
-#include "proxycertinfo.h"
+#include "openssl/x509v3.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -90,12 +90,12 @@ extern FILE *                           globus_i_gsi_cred_debug_fstream;
 #define GLOBUS_I_GSI_CRED_DEBUG_ENTER \
             GLOBUS_I_GSI_CRED_DEBUG_FPRINTF( \
                 2, (globus_i_gsi_cred_debug_fstream, \
-                    "%s entering\n", _function_name_))
+                    "%s entering\n", __func__))
 
 #define GLOBUS_I_GSI_CRED_DEBUG_EXIT \
             GLOBUS_I_GSI_CRED_DEBUG_FPRINTF( \
                 2, (globus_i_gsi_cred_debug_fstream, \
-                    "%s exiting\n", _function_name_))
+                    "%s exiting\n", __func__))
 
 /* ERROR MACROS */
 
@@ -105,7 +105,7 @@ extern FILE *                           globus_i_gsi_cred_debug_fstream;
             globus_common_create_string _ERRSTR_; \
         _RESULT_ = globus_i_gsi_cred_openssl_error_result(_ERRORTYPE_, \
                                                           __FILE__, \
-                                                          _function_name_, \
+                                                          __func__, \
                                                           __LINE__, \
                                                           _tmp_str_, \
                                                           NULL); \
@@ -118,7 +118,7 @@ extern FILE *                           globus_i_gsi_cred_debug_fstream;
             globus_common_create_string _ERRSTR_; \
         _RESULT_ = globus_i_gsi_cred_error_result(_ERRORTYPE_, \
                                                   __FILE__, \
-                                                  _function_name_, \
+                                                  __func__, \
                                                   __LINE__, \
                                                   _tmp_str_, \
                                                   NULL); \
@@ -129,7 +129,7 @@ extern FILE *                           globus_i_gsi_cred_debug_fstream;
     _TOP_RESULT_ = globus_i_gsi_cred_error_chain_result(_TOP_RESULT_, \
                                                         _ERRORTYPE_, \
                                                         __FILE__, \
-                                                        _function_name_, \
+                                                        __func__, \
                                                         __LINE__, \
                                                         NULL, \
                                                         NULL)
@@ -143,7 +143,7 @@ extern FILE *                           globus_i_gsi_cred_debug_fstream;
             globus_common_create_string _ERRSTR_; \
         _RESULT_ = globus_i_gsi_cred_openssl_error_result(_ERRORTYPE_, \
                                                           __FILE__, \
-                                                          _function_name_, \
+                                                          __func__, \
                                                           __LINE__, \
                                                           _tmp_str_, \
                                                           _LONG_DESC_); \
@@ -158,7 +158,7 @@ extern FILE *                           globus_i_gsi_cred_debug_fstream;
             globus_common_create_string _ERRSTR_; \
         _RESULT_ = globus_i_gsi_cred_error_result(_ERRORTYPE_, \
                                                   __FILE__, \
-                                                  _function_name_, \
+                                                  __func__, \
                                                   __LINE__, \
                                                   _tmp_str_, \
                                                   _LONG_DESC_); \
@@ -171,7 +171,7 @@ extern FILE *                           globus_i_gsi_cred_debug_fstream;
     _TOP_RESULT_ = globus_i_gsi_cred_error_chain_result(_TOP_RESULT_, \
                                                         _ERRORTYPE_, \
                                                         __FILE__, \
-                                                        _function_name_, \
+                                                        __func__, \
                                                         __LINE__, \
                                                         NULL, \
                                                         _LONG_DESC_)
@@ -223,7 +223,7 @@ globus_i_gsi_cred_goodtill(
 
 globus_result_t globus_i_gsi_cred_get_proxycertinfo(
     X509 *                              cert,
-    PROXYCERTINFO **                    proxycertinfo);
+    PROXY_CERT_INFO_EXTENSION **        proxycertinfo);
 
 int
 globus_i_gsi_cred_password_callback_no_prompt(
